<?php

namespace Microsoft\Graph\Generated\Models;

use Microsoft\Kiota\Abstractions\Enum;

class PayloadBrand extends Enum {
    public const UNKNOWN = "unknown";
    public const OTHER = "other";
    public const AMERICAN_EXPRESS = "americanExpress";
    public const CAPITAL_ONE = "capitalOne";
    public const DHL = "dhl";
    public const DOCU_SIGN = "docuSign";
    public const DROPBOX = "dropbox";
    public const FACEBOOK = "facebook";
    public const FIRST_AMERICAN = "firstAmerican";
    public const MICROSOFT = "microsoft";
    public const NETFLIX = "netflix";
    public const SCOTIABANK = "scotiabank";
    public const SEND_GRID = "sendGrid";
    public const STEWART_TITLE = "stewartTitle";
    public const TESCO = "tesco";
    public const WELLS_FARGO = "wellsFargo";
    public const SYRINX_CLOUD = "syrinxCloud";
    public const ADOBE = "adobe";
    public const TEAMS = "teams";
    public const ZOOM = "zoom";
    public const UNKNOWN_FUTURE_VALUE = "unknownFutureValue";
}
